% ---------------------------------
% author  : latexstudio
% website : www.latexstudio.net
% time    : 2022-01-04 10:26:39
% e-mail  : typeset@latexstudio.net
% ---------------------------------

\NeedsTeXFormat{LaTeX2e}[1999/12/01]
\ProvidesClass{aero}[2022/01/04, v1.0 by latexstudio.net]

\newif\if@linenumberon\global\@linenumberonfalse%
\DeclareOption{lineno}{\global\@linenumberontrue}%

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[oneside,a4paper,11pt]{article}

\RequirePackage{geometry}

\geometry{
top    = 3cm,
bottom = 3cm,
right  = 2.5cm,
left   = 2.5cm,
}

\RequirePackage[numbers,sort&compress]{natbib}
\RequirePackage{xcolor}

\RequirePackage{
expl3    , amsmath   , amsthm    , pdfpages      , siunitx  ,
fancyhdr , newtxtext , tikz      , tikzpagenodes , graphicx ,
marvosym , diagbox   , multirow  , amssymb       , url      ,
xpatch   , caption   , subfigure , etoolbox      ,
booktabs , array     , makecell  , enumitem      ,
}

\if@linenumberon%
\RequirePackage[mathlines,running]{lineno}
\let\linenumbershook\linenumbers
\else
\let\linenumbershook\empty
\fi%

\hyphenchar\font=-1
\linespread{1.6}
\sisetup{group-separator={\,},group-minimum-digits=4,separate-uncertainty=true}
\graphicspath{{res/},{figs/},{figures/}}
\newcolumntype{P}[1]{p{#1}<{\raggedright}}
\urlstyle{same}
\setlist{nosep}
\setlist[enumerate]{label=(\arabic*)}

\AtBeginEnvironment{tabular}{\small }
\AtBeginEnvironment{tabular*}{\small }
\AtBeginEnvironment{tabularx}{\small }

\tabcolsep 4pt
\aboverulesep 1pt
\belowrulesep 1pt
\bibsep           0pt plus .3pt minus .7pt
\parskip 0pt
\sfcode`.=1200
\sfcode`:=1200

\def\env@cases{%
  \let\@ifnextchar\new@ifnextchar
  \left\lbrace
  \def\arraystretch{1.2}%
  \array{@{~}l@{\quad}l@{}}%
}

\captionsetup{
  labelfont       = {bf},
  font            = {small},
  labelsep        = quad,
  aboveskip       = 8pt,
  singlelinecheck = true,
}
\captionsetup[figure]{
  name      = {Fig.},
  aboveskip = 8pt,
  belowskip = -3pt,
}
\captionsetup[table]{
  name      = {Table},
  skip      = 1pt,
  belowskip = 1pt,
}

\newcommand{\Nomenclature}{\section*{\normalsize Nomenclature}}
\newcommand{\cor}{{\rm (\Letter)}}
\newcommand{\note}[1]{{\normalsize\normalfont\color{blue}#1}}

\ExplSyntaxOn

\keys_define:nn { ADkeys } {
  name     . tl_set:N  = \l_ADkeys_name_tl,
  name     . initial:n = Astrodynamics,
  title    . tl_set:N  = \l_ADkeys_title_tl,
  title    . initial:n = Paper~title:~Preparation~of~papers~for~\textit{Astrodynamics},
  author   . tl_set:N  = \l_ADkeys_author_tl,
  author   . initial:n = {First~A.~Author$^{1}$,~Second~B.~Author$^{2}$,~and~Third~C.~Author$^{3}$},
  address  . tl_set:N  = \l_ADkeys_address_tl,
  address  . initial:n = {1.~Business~or~academic~affiliation~of~First~A.~Author,~with~city,~post~code,~and~country},
  email    . tl_set:N  = \l_ADkeys_email_tl,
  email    . initial:n = Corresponding~author's~name~and~email~address,
  abstract . tl_set:N  = \l_ADkeys_abstract_tl,
  abstract . initial:n = Abstract~content,
  keywords . tl_set:N  = \l_ADkeys_keywords_tl,
  keywords . initial:n = keywords~content,
  url      . tl_set:N  = \l_ADkeys_url_tl,
  url      . initial:n = https://mc03.manuscriptcentral.com/astrod,
}

\NewDocumentCommand\ADsetup{ +m }{
  \keys_set:nn{ADkeys}{#1}
}

\fancypagestyle{plain}{
  \fancyhf{}
  \renewcommand{\headrulewidth}{0pt}
  \fancyhead[L]{\itshape \l_ADkeys_name_tl}
  \fancyhead[R]{\l_ADkeys_url_tl}
}

\RenewDocumentCommand\maketitle{}{
  \pagestyle{plain}
  \linenumbershook
  \parindent 0pt
  \begingroup
  {\bfseries\LARGE\l_ADkeys_title_tl}\par
  \bigskip
  \l_ADkeys_author_tl\par
  \bigskip
  {\itshape\hangafter1\hangindent 1.06em \def\sep{\par \hangafter1\hangindent 1.06em} \l_ADkeys_address_tl}\par
  \bigskip
  {\Letter\ \l_ADkeys_email_tl}\par
  \bigskip
  \textbf{Abstract}\\
  \l_ADkeys_abstract_tl\par
  \bigskip
  \textbf{Keywords}\\
  {\def\sep{~·\ \ } \l_ADkeys_keywords_tl}
  \endgroup
  \parindent 1em
}

\ExplSyntaxOff

% MGStran class scratch pad registers
% dimen
\newdimen\@ADtrantmpdimenA
\newdimen\@ADtrantmpdimenB
% count
\newcount\@ADtrantmpcountA
\newcount\@ADtrantmpcountB
% token list
\newtoks\@ADtrantmptoksA

\def\@ADtranneedspace#1#2{\penalty-100\begingroup%shield temp variable
\@ADtrantmpdimenB\pagegoal\advance\@ADtrantmpdimenB-\pagetotal% space left
\ifdim #1>\@ADtrantmpdimenB\relax% not enough space left
\ifdim\@ADtrantmpdimenB>\z@\relax #2\fi%
\newpage%
\fi\endgroup}
\begingroup
\catcode`\Q=3
\long\gdef\@ifmtarg#1{\@xifmtarg#1QQ\@secondoftwo\@firstoftwo\@nil}
\long\gdef\@xifmtarg#1#2Q#3#4#5\@nil{#4}
\endgroup

\newcounter{biography}
\setcounter{biography}{0}

% photo area size
\def\@ADBIOphotowidth{1in}  % width of the biography photo area
\def\@ADBIOphotodepth{1.25in}  % depth (height) of the biography photo area
% area cleared for photo
\def\@ADBIOhangwidth{1.1in}  % width cleared for the biography photo area
\def\@ADBIOhangdepth{1in}  % depth cleared for the biography photo area
                 % actual depth will be a multiple of
                 % \baselineskip, rounded up
\def\@ADBIOskipN{2\baselineskip}% nominal value of the vskip above the biography

\newenvironment{biography}[2][]{\normalfont %
\unitlength 1in\parskip=0pt\par\parindent 1em\interlinepenalty500%
% we need enough space to support the hanging indent
% the nominal value of the spacer
% and one extra line for good measure
\@ADtrantmpdimenA=\@ADBIOhangdepth%
\advance\@ADtrantmpdimenA by \@ADBIOskipN%
\advance\@ADtrantmpdimenA by 1\baselineskip%
% if this page does not have enough space, break it and lets start
% with a new one
\@ADtranneedspace{\@ADtrantmpdimenA}{\relax}%
% nominal spacer can strech, not shrink use 1fil so user can out stretch with \vfill
% \vskip \@ADBIOskipN plus 1fil minus 0\baselineskip%
% the default box for where the photo goes
\def\@ADtempbiographybox{{\setlength{\fboxsep}{0pt}\framebox{%
\begin{minipage}[b][\@ADBIOphotodepth][c]{\@ADBIOphotowidth}\centering PLACE\\ PHOTO\\ HERE \end{minipage}}}}%
%
% detect if the optional argument was supplied, this requires the
% \@ifmtarg command as defined in the appendix section above
% and if so, override the default box with what they want
\@ifmtarg{#1}{\relax}{\def\@ADtempbiographybox{\mbox{\begin{minipage}[b][\@ADBIOphotodepth][c]{\@ADBIOphotowidth}%
\centering%
\includegraphics[width=25mm]{#1}%
\end{minipage}}}}% end if optional argument supplied
% Make an entry into the table of contents only if we have not done so before
%\if@biographyTOCentrynotmade%
%% link labels to the biography counter so hyperref will jump
%% to the biography, not the previous section
%\setcounter{biography}{-1}%
%\refstepcounter{biography}%
%\addcontentsline{toc}{section}{Biographies}%
%\global\@biographyTOCentrynotmadefalse%
%\fi%
% one more biography
\refstepcounter{biography}%
% Make an entry for this name into the table of contents
% \addcontentsline{toc}{subsection}{#2}%
% V1.6 properly handle if a new paragraph should occur while the
% hanging indent is still active. Do this by redefining \par so
% that it will not start a new paragraph. (But it will appear to the
% user as if it did.) Also, strip any leading pars, newlines, or spaces.
\let\@ADBIOORGparCMD=\par% save the original \par command
\edef\par{\hfil\break\indent}% the new \par will not be a "real" \par
\settoheight{\@ADtrantmpdimenA}{\@ADtempbiographybox}% get height of biography box
\@ADtrantmpdimenB=\@ADBIOhangdepth%
\@ADtrantmpcountA=\@ADtrantmpdimenB% countA has the hang depth
\divide\@ADtrantmpcountA by \baselineskip%  calculates lines needed to produce the hang depth
\advance\@ADtrantmpcountA by 1% ensure we overestimate
% set the hanging indent
\hangindent\@ADBIOhangwidth%
\hangafter-\@ADtrantmpcountA%
% reference the top of the photo area to the top of a capital T
\settoheight{\@ADtrantmpdimenB}{\mbox{T}}%
% set the photo box, give it zero width and height so as not to disturb anything
\noindent\makebox[0pt][l]{\hspace{-\@ADBIOhangwidth}\raisebox{\@ADtrantmpdimenB}[0pt][0pt]{%
\raisebox{-\@ADBIOphotodepth}[0pt][0pt]{\@ADtempbiographybox}}}%
% now place the author name and begin the bio text
\noindent{\textbf{#2}\ }}{\relax\let\par=\@ADBIOORGparCMD\par%
% 7/2001 V1.5 detect when the biography text is shorter than the photo area
% and pad the unused area - preventing a collision from the next biography entry
% MDS
\ifnum \prevgraf <\@ADtrantmpcountA\relax% detect when the biography text is shorter than the photo
    \advance\@ADtrantmpcountA by -\prevgraf% calculate how many lines we need to pad
    \advance\@ADtrantmpcountA by -1\relax% we compensate for the fact that we indented an extra line
    \@ADtrantmpdimenA=\baselineskip% calculate the length of the padding
    \multiply\@ADtrantmpdimenA by \@ADtrantmpcountA%
    \noindent\rule{0pt}{\@ADtrantmpdimenA}% insert an invisible support strut
\fi%
\par\normalfont}

\renewcommand\bibsection{}
\RequirePackage{hyperref}
\hypersetup{
% hidelinks,
CJKbookmarks       = true,
bookmarksnumbered  = true,
bookmarksopen      = true,
bookmarksopenlevel = 2,
unicode            = true,
colorlinks         = true,
breaklinks         = false,
backref            = false,
pdfsubject         = {www.latexstudio.net},
}

\endinput